@@ -3,24 +3,15 @@
 ### Default method.
 spmd.reduce.default <- function(x, x.buffer = NULL, op = .pbd_env$SPMD.CT$op,
     rank.dest = .pbd_env$SPMD.CT$rank.source, comm = .pbd_env$SPMD.CT$comm){
-  op <- match.arg(tolower(op[1]), .pbd_env$SPMD.OP)
-
-  if(op %in% c("land", "band", "lor", "bor", "lxor", "bxor")){
-    x <- as.integer(x)
-    if(!is.null(x.buffer)){
-      x.buffer <- as.integer(x.buffer)
-    }
-  }
-
+  comm <- as.integer(comm)
   all.array <- spmd.allreduce.integer(
                    as.integer(is.array(x) && length(x) > 0),
                    integer(1), op = "sum",
                    comm = comm) == spmd.comm.size(comm)
   if(all.array){
-    x <- spmd.allcheck.type(x, comm = comm)
-    spmd.reduce.array(x, op = op[1], rank.dest = rank.dest, comm = comm)
+    spmd.reduce.array(x, op = op, rank.dest = rank.dest, comm = comm)
   } else{
-    spmd.reduce.object(x, op = op[1], rank.dest = rank.dest, comm = comm)
+    spmd.reduce.object(x, op = op, rank.dest = rank.dest, comm = comm)
   }
 } # End of spmd.reduce.default().
 
@@ -30,7 +21,8 @@ spmd.reduce.integer <- function(x, x.buffer, op = .pbd_env$SPMD.CT$op,
     rank.dest = .pbd_env$SPMD.CT$rank.source, comm = .pbd_env$SPMD.CT$comm){
   ret <- .Call("spmd_reduce_integer", x, x.buffer,
                which(op[1] == .pbd_env$SPMD.OP),
-               as.integer(rank.dest), as.integer(comm), PACKAGE = "pbdMPI")
+               as.integer(rank.dest), as.integer(comm),
+               PACKAGE = "pbdMPI")
   if(spmd.comm.rank(comm) != rank.dest){
     return(invisible())
   }
@@ -41,13 +33,26 @@ spmd.reduce.double <- function(x, x.buffer, op = .pbd_env$SPMD.CT$op,
     rank.dest = .pbd_env$SPMD.CT$rank.source, comm = .pbd_env$SPMD.CT$comm){
   ret <- .Call("spmd_reduce_double", x, x.buffer,
                which(op[1] == .pbd_env$SPMD.OP),
-               as.integer(rank.dest), as.integer(comm), PACKAGE = "pbdMPI")
+               as.integer(rank.dest), as.integer(comm),
+               PACKAGE = "pbdMPI")
   if(spmd.comm.rank(comm) != rank.dest){
     return(invisible())
   }
   ret
 } # End of spmd.reduce.double().
 
+spmd.reduce.logical <- function(x, x.buffer, op = .pbd_env$SPMD.CT$op,
+    rank.dest = .pbd_env$SPMD.CT$rank.source, comm = .pbd_env$SPMD.CT$comm){
+  ret <- .Call("spmd_reduce_integer", x, x.buffer,
+               which(op[1] == .pbd_env$SPMD.OP),
+               as.integer(rank.dest), as.integer(comm),
+               PACKAGE = "pbdMPI")
+  if(spmd.comm.rank(comm) != rank.dest){
+    return(invisible())
+  }
+  as.logical(ret)
+} # End of spmd.reduce.logical().
+
 
 ### S4 methods.
 setGeneric(
@@ -71,3 +76,9 @@ setMethod(
   signature = signature(x = "numeric", x.buffer = "numeric"),
   definition = spmd.reduce.double
 )
+setMethod(
+  f = "reduce",
+  signature = signature(x = "logical", x.buffer = "logical"),
+  definition = spmd.reduce.logical
+)
+
