@@ -1,8 +1,9 @@
-library(pbdMPI, quietly = TRUE)
+suppressMessages(library(pbdMPI, quietly = TRUE))
 
 ### Define method.
 allgather.simple <- function(x, x.buffer = NULL, x.count = NULL,
-    displs = NULL, comm = .SPMD.CT$comm, unlist = .SPMD.CT$unlist){
+    displs = NULL, comm = .pbd_env$SPMD.CT$comm,
+    unlist = .pbd_env$SPMD.CT$unlist){
   ret <- allgather(as.integer(x@a[1]), x.buffer = integer(comm.size(comm)),
                    comm = comm)
   new("simple", a = ret)
